Struct openssl::bn::MsbOption [−][src]
pub struct MsbOption(_);Expand description
Options for the most significant bits of a randomly generated BigNum.
Implementations
The most significant bit of the number may be 0.
pub struct MsbOption(_);Options for the most significant bits of a randomly generated BigNum.
The most significant bit of the number may be 0.